@@ -2,6 +2,7 @@
 namespace TheSeer\Tokenizer;
 
 use PHPUnit\Framework\TestCase;
+use function file_get_contents;
 
 /**
  * @covers \TheSeer\Tokenizer\Tokenizer
@@ -18,6 +19,14 @@ class TokenizerTest extends TestCase {
         );
     }
 
+    public function testParsingCodeWithAmpersandReturnsCorrectToken(): void {
+        $result = (new Tokenizer())->parse('<?php function x(&$a) {}');
+        $this->assertEquals(
+            'T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG',
+            $result[5]->getName()
+        );
+    }
+
     /**
      * @ticket https://github.com/theseer/tokenizer/issues/13
      */
@@ -26,12 +35,12 @@ class TokenizerTest extends TestCase {
     }
 
     private function assertParsedTokensMatchFixture(string $fixture): void {
-        $expected = \unserialize(
-            \file_get_contents(__DIR__ . '/_files/' . $fixture . '.tokens'),
+        $expected = unserialize(
+            file_get_contents(__DIR__ . '/_files/' . $fixture . '.tokens'),
             [TokenCollection::class, Token::class]
         );
 
-        $actual = (new Tokenizer)->parse(\file_get_contents(__DIR__ . '/_files/' . $fixture));
+        $actual = (new Tokenizer)->parse(file_get_contents(__DIR__ . '/_files/' . $fixture));
         $this->assertEquals($expected, $actual);
     }
 }
